resize method
Reallocates the native rasterization buffer to the new dimensions and renders the current frame at the new resolution.
Implementation
Future<void> resize(int width, int height) =>
_invoke('resize', {'width': width, 'height': height});